EXPORTS
	??0CKeysData@@QAE@PAV0@@Z @ 1 NONAME ; CKeysData::CKeysData(class CKeysData *)
	??0CKeysData@@QAE@XZ @ 2 NONAME ; CKeysData::CKeysData(void)
	??0CSecurityPolicy@@QAE@XZ @ 3 NONAME ; CSecurityPolicy::CSecurityPolicy(void)
	??0TIpSecParser@@QAE@ABVTDesC16@@@Z @ 4 NONAME ; TIpSecParser::TIpSecParser(class TDesC16 const &)
	??0TKeyParser@@QAE@ABVTDesC16@@@Z @ 5 NONAME ; TKeyParser::TKeyParser(class TDesC16 const &)
	??0TPolicyParser@@QAE@ABVTDesC16@@@Z @ 6 NONAME ; TPolicyParser::TPolicyParser(class TDesC16 const &)
	??1CIpSecurityPiece@@UAE@XZ @ 7 NONAME ; CIpSecurityPiece::~CIpSecurityPiece(void)
	??1CKeysDataArray@@UAE@XZ @ 8 NONAME ; CKeysDataArray::~CKeysDataArray(void)
	??1CPolicySelector@@UAE@XZ @ 9 NONAME ; CPolicySelector::~CPolicySelector(void)
	??1CPolicySpec@@UAE@XZ @ 10 NONAME ; CPolicySpec::~CPolicySpec(void)
	?BufferAppend@TPolicyParser@@SAHAAPAVHBufC8@@ABVTDesC8@@@Z @ 11 NONAME ; int TPolicyParser::BufferAppend(class HBufC8 * &, class TDesC8 const &)
	?Construct@CKeysDataArray@@QAEXH@Z @ 12 NONAME ; void CKeysDataArray::Construct(int)
	?Construct@CPolicySelector@@QAEXXZ @ 13 NONAME ; void CPolicySelector::Construct(void)
	?Construct@CPolicySpec@@QAEXXZ @ 14 NONAME ; void CPolicySpec::Construct(void)
	?Construct@CSAList@@QAEXH@Z @ 15 NONAME ; void CSAList::Construct(int)
	?Construct@CSelectorList@@QAEXH@Z @ 16 NONAME ; void CSelectorList::Construct(int)
	?ConstructL@CIpSecurityPiece@@QAEXH@Z @ 17 NONAME ; void CIpSecurityPiece::ConstructL(int)
	?ConstructL@CKeysDataArray@@QAEXPAV1@@Z @ 18 NONAME ; void CKeysDataArray::ConstructL(class CKeysDataArray *)
	?ConstructL@CPolicySelector@@QAEXPAV1@@Z @ 19 NONAME ; void CPolicySelector::ConstructL(class CPolicySelector *)
	?ConstructL@CPolicySpec@@QAEXAAVTDesC16@@W4TPolicySpecType@@@Z @ 20 NONAME ; void CPolicySpec::ConstructL(class TDesC16 &, enum TPolicySpecType)
	?ConstructL@CPolicySpec@@QAEXPAV1@@Z @ 21 NONAME ; void CPolicySpec::ConstructL(class CPolicySpec *)
	?ConstructL@CSAList@@QAEXPAV1@@Z @ 22 NONAME ; void CSAList::ConstructL(class CSAList *)
	?ConstructL@CSecurityPolicy@@QAEXPAV1@@Z @ 23 NONAME ; void CSecurityPolicy::ConstructL(class CSecurityPolicy *)
	?ConstructL@CSecurityPolicy@@QAEXXZ @ 24 NONAME ; void CSecurityPolicy::ConstructL(void)
	?ConstructL@CSelectorList@@QAEXPAV1@PAVCSAPairList@@@Z @ 25 NONAME ; void CSelectorList::ConstructL(class CSelectorList *, class CSAPairList *)
	?CopyL@CKeysDataArray@@QAEXPAV1@@Z @ 26 NONAME ; void CKeysDataArray::CopyL(class CKeysDataArray *)
	?Empty@CKeysDataArray@@QAEXXZ @ 27 NONAME ; void CKeysDataArray::Empty(void)
	?FindSpec@CSecurityPolicy@@QAEPAVCPolicySpec@@ABVTDesC8@@@Z @ 28 NONAME ; class CPolicySpec * CSecurityPolicy::FindSpec(class TDesC8 const &)
	?NewL@CKeysDataArray@@SAPAV1@H@Z @ 29 NONAME ; class CKeysDataArray * CKeysDataArray::NewL(int)
	?NewL@CKeysDataArray@@SAPAV1@PAV1@@Z @ 30 NONAME ; class CKeysDataArray * CKeysDataArray::NewL(class CKeysDataArray *)
	?NewL@CPolicySelector@@SAPAV1@PAV1@@Z @ 31 NONAME ; class CPolicySelector * CPolicySelector::NewL(class CPolicySelector *)
	?NewL@CPolicySelector@@SAPAV1@XZ @ 32 NONAME ; class CPolicySelector * CPolicySelector::NewL(void)
	?NewL@CPolicySpec@@SAPAV1@AAVTDesC16@@W4TPolicySpecType@@@Z @ 33 NONAME ; class CPolicySpec * CPolicySpec::NewL(class TDesC16 &, enum TPolicySpecType)
	?NewL@CPolicySpec@@SAPAV1@PAV1@@Z @ 34 NONAME ; class CPolicySpec * CPolicySpec::NewL(class CPolicySpec *)
	?NewL@CPolicySpec@@SAPAV1@XZ @ 35 NONAME ; class CPolicySpec * CPolicySpec::NewL(void)
	?NewL@CSAList@@SAPAV1@H@Z @ 36 NONAME ; class CSAList * CSAList::NewL(int)
	?NewL@CSAList@@SAPAV1@PAV1@@Z @ 37 NONAME ; class CSAList * CSAList::NewL(class CSAList *)
	?NewL@CSelectorList@@SAPAV1@H@Z @ 38 NONAME ; class CSelectorList * CSelectorList::NewL(int)
	?NewL@CSelectorList@@SAPAV1@PAV1@PAVCSAPairList@@@Z @ 39 NONAME ; class CSelectorList * CSelectorList::NewL(class CSelectorList *, class CSAPairList *)
	?ParseAndIgnoreIKEL@TIpSecParser@@QAEHPAVCIpSecurityPiece@@@Z @ 40 NONAME ; int TIpSecParser::ParseAndIgnoreIKEL(class CIpSecurityPiece *)
	?ParseL@TIpSecParser@@QAEHPAVCIpSecurityPiece@@@Z @ 41 NONAME ; int TIpSecParser::ParseL(class CIpSecurityPiece *)
	?ParseL@TKeyParser@@QAEHPAVCKeysDataArray@@@Z @ 42 NONAME ; int TKeyParser::ParseL(class CKeysDataArray *)
	?ParseL@TPolicyParser@@QAEHPAVCIpSecurityPiece@@@Z @ 43 NONAME ; int TPolicyParser::ParseL(class CIpSecurityPiece *)
	?SetInfoL@CIpSecurityPiece@@QAEXABVTDesC16@@@Z @ 44 NONAME ; void CIpSecurityPiece::SetInfoL(class TDesC16 const &)
	?UseSA@CPolicySelector@@QAEHPAVCPolicySpec@@PAVTInetAddr@@@Z @ 45 NONAME ; int CPolicySelector::UseSA(class CPolicySpec *, class TInetAddr *)
	?Write@TIpSecParser@@SAHPAVCIpSecurityPiece@@AAPAVHBufC8@@@Z @ 46 NONAME ; int TIpSecParser::Write(class CIpSecurityPiece *, class HBufC8 * &)
	?Write@TKeyParser@@SAHPAVCKeysDataArray@@AAVRFile@@@Z @ 47 NONAME ; int TKeyParser::Write(class CKeysDataArray *, class RFile &)
	?Write@TPolicyParser@@SAHPAVCSecurityPolicy@@AAPAVHBufC8@@H@Z @ 48 NONAME ; int TPolicyParser::Write(class CSecurityPolicy *, class HBufC8 * &, int)
	?FQDNAddressListL@CIpSecurityPiece@@QAEPAV?$CArrayPtrFlat@VCSecpolBundleItem@@@@XZ @ 49 NONAME ; class CArrayPtrFlat<class CSecpolBundleItem> * CIpSecurityPiece::FQDNAddressListL(void)

